@@ -1,22 +1,22 @@
 /*
- * Copyright (C) 2011~2017 by CSSlayer
- * wengxt@gmail.com
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above Copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above Copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * 3. Neither the name of the authors nor the names of its contributors
- *    may be used to endorse or promote products derived from this
- *    software without specific prior written permission.
- */
+* Copyright (C) 2011~2017 by CSSlayer
+* wengxt@gmail.com
+*
+* Redistribution and use in source and binary forms, with or without
+* modification, are permitted provided that the following conditions
+* are met:
+*
+* 1. Redistributions of source code must retain the above Copyright
+*    notice, this list of conditions and the following disclaimer.
+*
+* 2. Redistributions in binary form must reproduce the above Copyright
+*    notice, this list of conditions and the following disclaimer in the
+*    documentation and/or other materials provided with the distribution.
+*
+* 3. Neither the name of the authors nor the names of its contributors
+*    may be used to endorse or promote products derived from this
+*    software without specific prior written permission.
+*/
 
 #include <QDBusConnection>
 #include <QDebug>
@@ -37,6 +37,8 @@
 #include "fcitxwatcher.h"
 #include "qfcitxplatforminputcontext.h"
 
+static bool key_filtered = false;
+
 static bool get_boolean_env(const char *name, bool defval) {
     const char *value = getenv(name);
 
@@ -85,11 +87,8 @@ struct xkb_context *_xkb_context_new_helper() {
 }
 
 QFcitxPlatformInputContext::QFcitxPlatformInputContext()
-    : m_watcher(new FcitxWatcher(
-          QDBusConnection::connectToBus(QDBusConnection::SessionBus,
-                                        "fcitx-platform-input-context"),
-          this)),
-      m_cursorPos(0), m_useSurroundingText(false),
+    : m_watcher(new FcitxWatcher(QDBusConnection::connectToBus(QDBusConnection::SessionBus, "fcitx-platform-input-context"), this)), m_cursorPos(0),
+      m_useSurroundingText(false),
       m_syncMode(get_boolean_env("FCITX_QT_USE_SYNC", false)), m_destroy(false),
       m_xkbContext(_xkb_context_new_helper()),
       m_xkbComposeTable(m_xkbContext ? xkb_compose_table_new_from_locale(
@@ -278,21 +277,14 @@ void QFcitxPlatformInputContext::setFocusObject(QObject *object) {
     QWindow *window = qApp->focusWindow();
     m_lastWindow = window;
     m_lastObject = object;
-    // Always create IC Data for window.
-    if (window) {
-        proxy = validICByWindow(window);
-        if (!proxy) {
-            createICData(window);
-        }
-    }
-    if (!window || (!inputMethodAccepted() && !objectAcceptsInputMethod())) {
-        m_lastWindow = nullptr;
-        m_lastObject = nullptr;
+    if (!window) {
         return;
     }
-    if (proxy) {
-        cursorRectChanged();
+    proxy = validICByWindow(window);
+    if (proxy)
         proxy->focusIn();
+    else {
+        createICData(window);
     }
 }
 
@@ -322,15 +314,6 @@ void QFcitxPlatformInputContext::cursorRectChanged() {
         return;
     }
 
-    if (data.capability & CAPACITY_RELATIVE_CURSOR_RECT) {
-        auto margins = inputWindow->frameMargins();
-        r.translate(margins.left(), margins.top());
-        if (data.rect != r) {
-            data.rect = r;
-            proxy->setCursorRect(r.x(), r.y(), r.width(), r.height());
-        }
-        return;
-    }
     qreal scale = inputWindow->devicePixelRatio();
     auto screenGeometry = inputWindow->screen()->geometry();
     auto point = inputWindow->mapToGlobal(r.topLeft());
@@ -351,17 +334,17 @@ void QFcitxPlatformInputContext::createInputContextFinished() {
     if (!proxy) {
         return;
     }
-    auto w = static_cast<QWindow *>(proxy->property("wid").value<void *>());
+    auto w =
+        reinterpret_cast<QWindow *>(proxy->property("wid").value<void *>());
     FcitxQtICData *data =
         static_cast<FcitxQtICData *>(proxy->property("icData").value<void *>());
     data->rect = QRect();
 
     if (proxy->isValid()) {
         QWindow *window = qApp->focusWindow();
-        if (window && window == w && inputMethodAccepted() &&
-            objectAcceptsInputMethod()) {
-            cursorRectChanged();
+        if (window && window == w) {
             proxy->focusIn();
+            cursorRectChanged();
         }
     }
 
@@ -372,9 +355,8 @@ void QFcitxPlatformInputContext::createInputContextFinished() {
     flag |= CAPACITY_GET_IM_INFO_ON_FOCUS;
     m_useSurroundingText =
         get_boolean_env("FCITX_QT_ENABLE_SURROUNDING_TEXT", true);
-    if (m_useSurroundingText) {
+    if (m_useSurroundingText)
         flag |= CAPACITY_SURROUNDING_TEXT;
-    }
 
     if (qApp && qApp->platformName() == "wayland") {
         flag |= CAPACITY_RELATIVE_CURSOR_RECT;
@@ -533,20 +515,14 @@ void QFcitxPlatformInputContext::deleteSurroundingText(int offset,
 
 void QFcitxPlatformInputContext::forwardKey(uint keyval, uint state,
                                             bool type) {
-    auto proxy = qobject_cast<FcitxInputContextProxy *>(sender());
-    if (!proxy) {
-        return;
-    }
-    FcitxQtICData &data = *static_cast<FcitxQtICData *>(
-        proxy->property("icData").value<void *>());
-    auto w = static_cast<QWindow *>(proxy->property("wid").value<void *>());
     QObject *input = qApp->focusObject();
-    auto window = qApp->focusWindow();
-    if (input && window && w == window) {
-        std::unique_ptr<QKeyEvent> keyevent{
-            createKeyEvent(keyval, state, type, data.event.get())};
+    if (input != nullptr) {
+        key_filtered = true;
+        QKeyEvent *keyevent = createKeyEvent(keyval, state, type);
 
-        forwardEvent(window, *keyevent);
+        QCoreApplication::sendEvent(input, keyevent);
+        delete keyevent;
+        key_filtered = false;
     }
 }
 
@@ -582,9 +558,9 @@ void QFcitxPlatformInputContext::createICData(QWindow *w) {
             data.proxy->setDisplay("wayland:");
         }
         data.proxy->setProperty("wid",
-                                QVariant::fromValue(static_cast<void *>(w)));
-        data.proxy->setProperty(
-            "icData", QVariant::fromValue(static_cast<void *>(&data)));
+                                qVariantFromValue(static_cast<void *>(w)));
+        data.proxy->setProperty("icData",
+                                qVariantFromValue(static_cast<void *>(&data)));
         connect(data.proxy, &FcitxInputContextProxy::inputContextCreated, this,
                 &QFcitxPlatformInputContext::createInputContextFinished);
         connect(data.proxy, &FcitxInputContextProxy::commitString, this,
@@ -601,76 +577,38 @@ void QFcitxPlatformInputContext::createICData(QWindow *w) {
 }
 
 QKeyEvent *QFcitxPlatformInputContext::createKeyEvent(uint keyval, uint state,
-                                                      bool isRelease,
-                                                      const QKeyEvent *event) {
-    QKeyEvent *newEvent = nullptr;
-    if (event && event->nativeVirtualKey() == keyval &&
-        event->nativeModifiers() == state &&
-        isRelease == (event->type() == QEvent::KeyRelease)) {
-        newEvent = new QKeyEvent(*event);
-    } else {
-        Qt::KeyboardModifiers qstate = Qt::NoModifier;
+                                                      bool isRelease) {
+    Qt::KeyboardModifiers qstate = Qt::NoModifier;
 
-        int count = 1;
-        if (state & FcitxKeyState_Alt) {
-            qstate |= Qt::AltModifier;
-            count++;
-        }
-
-        if (state & FcitxKeyState_Shift) {
-            qstate |= Qt::ShiftModifier;
-            count++;
-        }
-
-        if (state & FcitxKeyState_Ctrl) {
-            qstate |= Qt::ControlModifier;
-            count++;
-        }
-
-        auto unicode = xkb_keysym_to_utf32(keyval);
-        QString text;
-        if (unicode) {
-            text = QString::fromUcs4(&unicode, 1);
-        }
-
-        int key = keysymToQtKey(keyval, text);
-
-        newEvent =
-            new QKeyEvent(isRelease ? (QEvent::KeyRelease) : (QEvent::KeyPress),
-                          key, qstate, 0, keyval, state, text, false, count);
-        if (event) {
-            newEvent->setTimestamp(event->timestamp());
-        }
+    int count = 1;
+    if (state & FcitxKeyState_Alt) {
+        qstate |= Qt::AltModifier;
+        count++;
     }
 
-    return newEvent;
-}
-
-void QFcitxPlatformInputContext::forwardEvent(QWindow *window,
-                                              const QKeyEvent &keyEvent) {
-    // use same variable name as in QXcbKeyboard::handleKeyEvent
-    QEvent::Type type = keyEvent.type();
-    int qtcode = keyEvent.key();
-    Qt::KeyboardModifiers modifiers = keyEvent.modifiers();
-    quint32 code = keyEvent.nativeScanCode();
-    quint32 sym = keyEvent.nativeVirtualKey();
-    quint32 state = keyEvent.nativeModifiers();
-    QString string = keyEvent.text();
-    bool isAutoRepeat = keyEvent.isAutoRepeat();
-    ulong time = keyEvent.timestamp();
-    // copied from QXcbKeyboard::handleKeyEvent()
-    if (type == QEvent::KeyPress && qtcode == Qt::Key_Menu) {
-        QPoint globalPos, pos;
-        if (window->screen()) {
-            globalPos = window->screen()->handle()->cursor()->pos();
-            pos = window->mapFromGlobal(globalPos);
-        }
-        QWindowSystemInterface::handleContextMenuEvent(window, false, pos,
-                                                       globalPos, modifiers);
+    if (state & FcitxKeyState_Shift) {
+        qstate |= Qt::ShiftModifier;
+        count++;
     }
-    QWindowSystemInterface::handleExtendedKeyEvent(window, time, type, qtcode,
-                                                   modifiers, code, sym, state,
-                                                   string, isAutoRepeat);
+
+    if (state & FcitxKeyState_Ctrl) {
+        qstate |= Qt::ControlModifier;
+        count++;
+    }
+
+    auto unicode = xkb_keysym_to_utf32(keyval);
+    QString text;
+    if (unicode) {
+        text = QString::fromUcs4(&unicode, 1);
+    }
+
+    int key = keysymToQtKey(keyval, text);
+
+    QKeyEvent *keyevent =
+        new QKeyEvent(isRelease ? (QEvent::KeyRelease) : (QEvent::KeyPress),
+                      key, qstate, 0, keyval, state, text, false, count);
+
+    return keyevent;
 }
 
 bool QFcitxPlatformInputContext::filterEvent(const QEvent *event) {
@@ -686,6 +624,10 @@ bool QFcitxPlatformInputContext::filterEvent(const QEvent *event) {
         quint32 state = keyEvent->nativeModifiers();
         bool isRelease = keyEvent->type() == QEvent::KeyRelease;
 
+        if (key_filtered) {
+            break;
+        }
+
         if (!inputMethodAccepted() && !objectAcceptsInputMethod())
             break;
 
@@ -753,10 +695,14 @@ void QFcitxPlatformInputContext::processKeyEventFinished(
 
     // use same variable name as in QXcbKeyboard::handleKeyEvent
     QEvent::Type type = keyEvent.type();
+    int qtcode = keyEvent.key();
+    Qt::KeyboardModifiers modifiers = keyEvent.modifiers();
     quint32 code = keyEvent.nativeScanCode();
     quint32 sym = keyEvent.nativeVirtualKey();
     quint32 state = keyEvent.nativeModifiers();
     QString string = keyEvent.text();
+    bool isAutoRepeat = keyEvent.isAutoRepeat();
+    ulong time = keyEvent.timestamp();
 
     if (!proxy->processKeyEventResult(*watcher)) {
         filtered =
@@ -770,14 +716,19 @@ void QFcitxPlatformInputContext::processKeyEventFinished(
     }
 
     if (!filtered) {
-        forwardEvent(window, keyEvent);
-    } else {
-        auto proxy = qobject_cast<FcitxInputContextProxy *>(watcher->parent());
-        if (proxy) {
-            FcitxQtICData &data = *static_cast<FcitxQtICData *>(
-                proxy->property("icData").value<void *>());
-            data.event.reset(new QKeyEvent(keyEvent));
+        // copied from QXcbKeyboard::handleKeyEvent()
+        if (type == QEvent::KeyPress && qtcode == Qt::Key_Menu) {
+            QPoint globalPos, pos;
+            if (window->screen()) {
+                globalPos = window->screen()->handle()->cursor()->pos();
+                pos = window->mapFromGlobal(globalPos);
+            }
+            QWindowSystemInterface::handleContextMenuEvent(
+                window, false, pos, globalPos, modifiers);
         }
+        QWindowSystemInterface::handleExtendedKeyEvent(
+            window, time, type, qtcode, modifiers, code, sym, state, string,
+            isAutoRepeat);
     }
 
     delete watcher;
